import {createRouter, createWebHistory} from 'vue-router'
import Dashboard from '@/views/Dashboard.vue';
import Login from '@/views/Login.vue';
import Register from '@/views/Register.vue';
import store from '@/store';
import Friends from "@/views/Friends.vue";
import Inventory from '@/views/Inventory.vue';
import InventoryDetail from "@/views/InventoryDetail.vue";


const routes = [
    {path: '/', component: Dashboard, meta: {requiresAuth: true}},
    {path: '/inventory', component: Inventory, meta: {requiresAuth: true}},
    {path: '/inventory/:id', component: InventoryDetail, meta: {requiresAuth: true}, props: true},
    {path: '/friends', component: Friends, meta: {requiresAuth: true}},
    {path: '/login', component: Login, meta: {requiresAuth: false}},
    {path: '/register', component: Register, meta: {requiresAuth: false}},
    {path: '/:pathMatch(.*)*', redirect: '/'}
]

const router = createRouter({
    history: createWebHistory(),
    linkActiveClass: "active",
    routes,
})

router.beforeEach((to/*, from*/) => {
    // if this route requires auth, check if logged in, if not, redirect to login page.
    if (to.meta.requiresAuth && !store.getters.isLoggedIn) {
        console.log("Not logged in, redirecting to login page")
        return {
            path: '/login',
            // save the location we were at to come back later
            query: {redirect: to.fullPath},
        }
    }
})

export default router